@@ -1,5 +1,5 @@
 var searchData=
 [
-  ['0_0',['0',['../changelog.html#log_1_10_0',1,'Release 1.10.0'],['../changelog.html#log_1_8_0',1,'Release 1.8.0'],['../changelog.html#log_1_9_0',1,'Release 1.9.0']]],
+  ['0_0',['0',['../changelog.html#log_1_10_0',1,'Release 1.10.0'],['../changelog.html#log_1_11_0',1,'Release 1.11.0'],['../changelog.html#log_1_8_0',1,'Release 1.8.0'],['../changelog.html#log_1_9_0',1,'Release 1.9.0']]],
   ['0_3a_20check_20if_20doxygen_20supports_20your_20programming_20hardware_20description_20language_1',['Step 0: Check if doxygen supports your programming/hardware description language',['../starting.html#step0',1,'']]]
 ];
